@@ -601,11 +601,13 @@ def main(sys_args=None):
         help="Run ansible-runner in the foreground"
     )
     add_args_to_parser(run_subparser, DEFAULT_CLI_ARGS['positional_args'])
+    add_args_to_parser(run_subparser, DEFAULT_CLI_ARGS['playbook_group'])
     start_subparser = subparser.add_parser(
         'start',
         help="Start an ansible-runner process in the background"
     )
     add_args_to_parser(start_subparser, DEFAULT_CLI_ARGS['positional_args'])
+    add_args_to_parser(start_subparser, DEFAULT_CLI_ARGS['playbook_group'])
     stop_subparser = subparser.add_parser(
         'stop',
         help="Stop an ansible-runner process that's running in the background"
@@ -750,7 +752,6 @@ def main(sys_args=None):
         print_common_usage()
         parser.exit(status=0)
 
-
     args = parser.parse_args(sys_args)
 
     vargs = vars(args)
