@@ -12,7 +12,13 @@ from ansible_runner.exceptions import ConfigurationError
 
 def test_ansible_config_defaults():
     rc = CommandConfig()
-    assert rc.private_data_dir == os.path.join(gettempdir(), ".ansible-runner")
+
+    # Check that the private data dir is placed in our default location with our default prefix
+    # and has some extra uniqueness on the end.
+    base_private_data_dir = os.path.join(gettempdir(), '.ansible-runner-')
+    assert rc.private_data_dir.startswith(base_private_data_dir)
+    assert len(rc.private_data_dir) > len(base_private_data_dir)
+
     assert rc.execution_mode == BaseExecutionMode.NONE
     assert rc.runner_mode is None
 
@@ -83,7 +89,7 @@ def test_prepare_run_command_with_containerization(tmpdir, container_runtime):
                              ['-v', '{}/:{}/'.format(cwd, cwd), '-v', '{}/.ssh/:/home/runner/.ssh/'.format(os.environ['HOME'])]
 
     if container_runtime == 'podman':
-        expected_command_start +=['--group-add=root', '--userns=keep-id', '--ipc=host']
+        expected_command_start += ['--group-add=root', '--ipc=host']
 
     expected_command_start += ['-v', '{}/artifacts/:/runner/artifacts/:Z'.format(rc.private_data_dir)] + \
         ['-v', '{}/:/runner/:Z'.format(rc.private_data_dir)] + \
