@@ -13,7 +13,13 @@ from ansible_runner.utils import get_executable_path
 
 def test_ansible_inventory_init_defaults():
     rc = InventoryConfig()
-    assert rc.private_data_dir == os.path.join(gettempdir(), ".ansible-runner")
+
+    # Check that the private data dir is placed in our default location with our default prefix
+    # and has some extra uniqueness on the end.
+    base_private_data_dir = os.path.join(gettempdir(), '.ansible-runner-')
+    assert rc.private_data_dir.startswith(base_private_data_dir)
+    assert len(rc.private_data_dir) > len(base_private_data_dir)
+
     assert rc.execution_mode == BaseExecutionMode.ANSIBLE_COMMANDS
 
 
@@ -105,7 +111,7 @@ def test_prepare_inventory_command_with_containerization(tmpdir, container_runti
     expected_command_start = [container_runtime, 'run', '--rm', '--interactive', '--workdir', '/runner/project'] + \
                              ['-v', '{}/.ssh/:/home/runner/.ssh/'.format(os.environ['HOME'])]
     if container_runtime == 'podman':
-        expected_command_start +=['--group-add=root', '--userns=keep-id', '--ipc=host']
+        expected_command_start += ['--group-add=root', '--ipc=host']
 
     expected_command_start += ['-v', '{}/artifacts/:/runner/artifacts/:Z'.format(rc.private_data_dir)] + \
         ['-v', '{}/:/runner/:Z'.format(rc.private_data_dir)] + \
