@@ -4,14 +4,15 @@ import codecs
 import os
 
 import json
-import mock
+from unittest import mock
 import pexpect
 import pytest
 import six
+import sys
 
 from ansible_runner import Runner
-from ansible_runner.exceptions import CallbackError
-from ansible_runner.runner_config import RunnerConfig
+from ansible_runner.exceptions import CallbackError, AnsibleRunnerException
+from ansible_runner.config.runner import RunnerConfig
 
 HERE, FILENAME = os.path.split(__file__)
 
@@ -26,7 +27,7 @@ def rc(request, tmpdir):
     }
     rc.cwd = str(tmpdir)
     rc.env = {}
-    rc.job_timeout = .1
+    rc.job_timeout = .5
     rc.idle_timeout = 0
     rc.pexpect_timeout = .1
     rc.pexpect_use_poll = True
@@ -59,7 +60,7 @@ def test_error_code(rc):
 
 # TODO: matt does not like this test
 def test_job_timeout(rc):
-    rc.command = ['python', '-c', 'import time; time.sleep(5)']
+    rc.command = [sys.executable, '-c', 'import time; time.sleep(5)']
     runner = Runner(config=rc)
     status, exitcode = runner.run()
     assert status == 'timeout'
@@ -67,7 +68,7 @@ def test_job_timeout(rc):
 
 
 def test_cancel_callback(rc):
-    rc.command = ['python', '-c', 'print(input("Password: "))']
+    rc.command = [sys.executable, '-c', 'print(input("Password: "))']
     status, exitcode = Runner(config=rc, cancel_callback=lambda: True).run()
     assert status == 'canceled'
 
@@ -76,14 +77,24 @@ def test_cancel_callback_error(rc):
     def kaboom():
         raise Exception('kaboom')
 
-    rc.command = ['python', '-c', 'print(input("Password: "))']
+    rc.command = [sys.executable, '-c', 'print(input("Password: "))']
     with pytest.raises(CallbackError):
         Runner(config=rc, cancel_callback=kaboom).run()
 
 
+def test_verbose_event_created_time(rc):
+    rc.command = ['echo', 'helloworld']
+    runner = Runner(config=rc)
+    status, exitcode = runner.run()
+    assert status == 'successful'
+    assert exitcode == 0
+    for event in runner.events:
+        assert 'created' in event, event
+
+
 @pytest.mark.parametrize('value', ['abc123', six.u('Iñtërnâtiônàlizætiøn')])
 def test_env_vars(rc, value):
-    rc.command = ['python', '-c', 'import os; print(os.getenv("X_MY_ENV"))']
+    rc.command = [sys.executable, '-c', 'import os; print(os.getenv("X_MY_ENV"))']
     rc.env = {'X_MY_ENV': value}
     status, exitcode = Runner(config=rc).run()
     assert status == 'successful'
@@ -92,16 +103,32 @@ def test_env_vars(rc, value):
         assert value in f.read()
 
 
+def test_event_callback_data_check(rc):
+    rc.ident = "testident"
+    rc.check_job_event_data = True
+    runner = Runner(config=rc, remove_partials=False)
+    runner.event_handler = mock.Mock()
+
+    with pytest.raises(AnsibleRunnerException) as exc:
+        runner.event_callback(dict(uuid="testuuid", counter=0))
+
+    assert "Failed to open ansible stdout callback plugin partial data" in str(exc)
+
+
 def test_event_callback_interface_has_ident(rc):
     rc.ident = "testident"
     runner = Runner(config=rc, remove_partials=False)
     runner.event_handler = mock.Mock()
     with mock.patch('codecs.open', mock.mock_open(read_data=json.dumps(dict(event="test")))):
         with mock.patch('os.chmod', mock.Mock()) as chmod:
-            runner.event_callback(dict(uuid="testuuid", counter=0))
-            assert runner.event_handler.call_count == 1
-            runner.event_handler.assert_called_with(dict(runner_ident='testident', counter=0, uuid='testuuid', event='test'))
-            chmod.assert_called_once()
+            with mock.patch('os.mkdir', mock.Mock()):
+                runner.event_callback(dict(uuid="testuuid", counter=0))
+    assert runner.event_handler.call_count == 1
+    runner.event_handler.assert_called_with(dict(
+        runner_ident='testident', counter=0, uuid='testuuid', event='test',
+        created=mock.ANY
+    ))
+    chmod.assert_called_once()
     runner.status_callback("running")
 
 
@@ -109,9 +136,13 @@ def test_event_callback_interface_calls_event_handler_for_verbose_event(rc):
     rc.ident = "testident"
     event_handler = mock.Mock()
     runner = Runner(config=rc, event_handler=event_handler)
-    runner.event_callback(dict(uuid="testuuid", event='verbose', counter=0))
+    with mock.patch('os.mkdir', mock.Mock()):
+        runner.event_callback(dict(uuid="testuuid", event='verbose', counter=0))
     assert event_handler.call_count == 1
-    event_handler.assert_called_with(dict(runner_ident='testident', counter=0, uuid='testuuid', event='verbose'))
+    event_handler.assert_called_with(dict(
+        runner_ident='testident', counter=0, uuid='testuuid', event='verbose',
+        created=mock.ANY
+    ))
 
 
 def test_status_callback_interface(rc):
